mailr2765 - in /branches/tensor_pdb: generic_fns/pdb.py prompt/pdb.py prompt/pymol.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward . dauvergne on November 07, 2006 - 07:29:
Author: bugman
Date: Tue Nov  7 06:52:16 2006
New Revision: 2765

URL: http://svn.gna.org/viewcvs/relax?rev=2765&view=rev
Log:
Spell check of the PDB and PyMOL user functions and generic_fns code.


Modified:
    branches/tensor_pdb/generic_fns/pdb.py
    branches/tensor_pdb/prompt/pdb.py
    branches/tensor_pdb/prompt/pymol.py

Modified: branches/tensor_pdb/generic_fns/pdb.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/tensor_pdb/generic_fns/pdb.py?rev=2765&r1=2764&r2=2765&view=diff
==============================================================================
--- branches/tensor_pdb/prompt/pdb.py (original)
+++ branches/tensor_pdb/prompt/pdb.py Tue Nov  7 06:52:16 2006
@@ -66,7 +66,7 @@
         
         There are four different types of residue within the PDB.  The 
centre of mass of the
         selected residues is represented as a single carbon atom of the 
residue 'COM'.  The
-        ellipsoidal geometric shape constists of numberous H atoms of the 
residue 'TNS'.  The axes
+        ellipsoidal geometric shape consists of numerous H atoms of the 
residue 'TNS'.  The axes
         of the tensor, when defined, are presented as the residue 'AXS' and 
consist of carbon atoms:
         one at the centre of mass and one at the end of each eigenvector.  
Finally, if Monte Carlo
         simulations were run and the diffusion tensor parameters were 
allowed to vary then there

Modified: branches/tensor_pdb/prompt/pymol.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/tensor_pdb/prompt/pymol.py?rev=2765&r1=2764&r2=2765&view=diff
==============================================================================
--- branches/tensor_pdb/prompt/pymol.py (original)
+++ branches/tensor_pdb/prompt/pymol.py Tue Nov  7 06:52:16 2006
@@ -165,7 +165,7 @@
         ~~~~~~~~~~~
 
         This function allows residues specific values to be mapped to a 
structure through PyMOL
-        macros.  Currently only the 'classic' style, which is described 
below, is availible.
+        macros.  Currently only the 'classic' style, which is described 
below, is available.
 
 
         Colour
@@ -365,7 +365,7 @@
         This function allows residues specific values to be mapped to a 
structure through the
         creation of a PyMOL macro which can be executed in PyMOL by clicking 
on 'File,
         Macro, Execute User...'.  Currently only the 'classic' style, which 
is described below, is
-        availible.
+        available.
 
 
         Colour




Related Messages


Powered by MHonArc, Updated Tue Nov 07 07:40:11 2006
--- branches/tensor_pdb/generic_fns/pdb.py (original)
+++ branches/tensor_pdb/generic_fns/pdb.py Tue Nov  7 06:52:16 2006
@@ -219,7 +219,7 @@
 
         # Final print out.
         print "    Total mass:      M = " + `M`
-        print "    Center of mass:  R = " + `R`
+        print "    Centre of mass:  R = " + `R`
 
         # Return the centre of mass.
         return R
@@ -266,7 +266,7 @@
         res_num = 1
 
 
         # Center of mass.
         #################
 
         # Calculate the centre of mass.
@@ -408,7 +408,7 @@
         @type chain_id:     str
         @param res_num:     The residue number.
         @type res_num:      int
-        @param R:           The center of mass.
+        @param R:           The centre of mass.
         @type R:            Numeric array (Float64)
         @param i:           The Monte Carlo simulation index.
         @type i:            int
@@ -499,7 +499,7 @@
         @type chain_id:     str
         @param res_num:     The residue number.
         @type res_num:      int
-        @param R:           The center of mass.
+        @param R:           The centre of mass.
         @type R:            Numeric array (Float64)
         @param i:           The Monte Carlo simulation index.
         @type i:            int
@@ -938,7 +938,7 @@
             v in [0, 1].
 
         Because theta is defined between [0, pi] and phi is defined between 
[0, 2pi], for a uniform
-        distribution u is only incremented half of 'inc'.  The unit vectors 
are gerenated using the
+        distribution u is only incremented half of 'inc'.  The unit vectors 
are generated using the
         equation
 
@@ -266,7 +266,7 @@
 
 
-        # Center of mass.
+        # Centre of mass.
         #################
 
                        | cos(theta) * sin(phi) |

Modified: branches/tensor_pdb/prompt/pdb.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/tensor_pdb/prompt/pdb.py?rev=2765&r1=2764&r2=2765&view=diff
==============================================================================